@@ -5,8 +5,8 @@
 
 #include "ev-view-type-builtins.h"
 
-/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-document-model.h" */
-#include "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-document-model.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-document-model.h" */
+#include "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-document-model.h"
 GType
 ev_sizing_mode_get_type (void)
 {
@@ -28,8 +28,8 @@ ev_sizing_mode_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-jobs.h" */
-#include "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-jobs.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-jobs.h" */
+#include "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-jobs.h"
 GType
 ev_job_run_mode_get_type (void)
 {
@@ -77,8 +77,8 @@ ev_job_page_data_flags_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-job-scheduler.h" */
-#include "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-job-scheduler.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-job-scheduler.h" */
+#include "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-job-scheduler.h"
 GType
 ev_job_priority_get_type (void)
 {
@@ -102,8 +102,8 @@ ev_job_priority_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-view.h" */
-#include "/usr/src/ports/atril/atril-1.10.2-1.i686/src/atril-1.10.2/libview/ev-view.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-view.h" */
+#include "/usr/src/ports/atril/atril-1.18.0-1.x86_64/src/atril-1.18.0/libview/ev-view.h"
 GType
 ev_view_selection_mode_get_type (void)
 {
